from flask import Flask, render_template_string, redirect, url_for, request, session
from flask_sqlalchemy import SQLAlchemy
from datetime import datetime

app = Flask(__name__)
app.secret_key = 'your_secret_key'
app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///dashboard.db'  # Use SQLite for simplicity
db = SQLAlchemy(app)

# Database Models
class User(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    first_name = db.Column(db.String(255))
    last_name = db.Column(db.String(255))
    email = db.Column(db.String(255), unique=True)
    role = db.Column(db.String(50))  # Roles: 'Admin', 'Managing Director', 'Program Officer', 'Member Account'

class Donation(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    donor_name = db.Column(db.String(255))
    amount = db.Column(db.Float)
    payment_method = db.Column(db.String(50))
    donation_date = db.Column(db.DateTime, default=datetime.utcnow)

# Create database tables
@app.before_first_request
def create_tables():
    db.create_all()
    # Sample data
    if not User.query.first():
        db.session.add(User(first_name="Admin", last_name="User", email="admin@example.com", role="Admin"))
        db.session.add(User(first_name="Managing", last_name="Director", email="md@example.com", role="Managing Director"))
        db.session.add(User(first_name="Program", last_name="Officer", email="po@example.com", role="Program Officer"))
        db.session.add(User(first_name="Member", last_name="Account", email="member@example.com", role="Member Account"))
        db.session.commit()

@app.route('/')
def index():
    return redirect(url_for('login'))

@app.route('/login', methods=['GET', 'POST'])
def login():
    if request.method == 'POST':
        email = request.form['email']
        user = User.query.filter_by(email=email).first()
        if user:
            session['user_id'] = user.id
            return redirect(url_for('dashboard'))
    return render_template_string(LOGIN_TEMPLATE)

@app.route('/dashboard')
def dashboard():
    if 'user_id' not in session:
        return redirect(url_for('login'))
    
    user = User.query.get(session['user_id'])
    content = generate_dashboard_content(user.role)
    
    return render_template_string(DASHBOARD_TEMPLATE, user=user, content=content)

def generate_dashboard_content(role):
    if role == 'Admin':
        return "Admin Dashboard with full access."
    elif role == 'Managing Director':
        return "Managing Director Dashboard."
    elif role == 'Program Officer':
        return "Program Officer Dashboard."
    elif role == 'Member Account':
        return "Member Dashboard with limited access."
    return "Role not recognized."

@app.route('/donations')
def donations():
    if 'user_id' not in session:
        return redirect(url_for('login'))
    
    donations = Donation.query.all()
    return render_template_string(DONATIONS_TEMPLATE, donations=donations)

@app.route('/logout')
def logout():
    session.pop('user_id', None)
    return redirect(url_for('login'))

# HTML Templates as strings
LOGIN_TEMPLATE = '''
<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <title>Login</title>
    <style>
        body { background-color: #f8f9fa; }
        .login-form { max-width: 400px; margin: auto; padding: 15px; background: white; border-radius: 10px; box-shadow: 0 0 20px rgba(0,0,0,0.1); }
    </style>
</head>
<body>
    <div class="login-form">
        <h2 class="text-center">Login</h2>
        <form method="post">
            <div class="form-group">
                <label for="email">Email</label>
                <input type="text" name="email" class="form-control" required>
            </div>
            <button type="submit" class="btn btn-primary btn-block">Login</button>
        </form>
    </div>
</body>
</html>
'''

DASHBOARD_TEMPLATE = '''
<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <title>Dashboard</title>
    <style>
        body { background-color: #e9ecef; }
        .sidebar { background-color: #343a40; color: white; }
        .sidebar a { color: white; }
        .sidebar a:hover { background-color: #495057; }
    </style>
</head>
<body>
    <div class="d-flex">
        <div class="sidebar p-3" style="width: 250px;">
            <h4>{{ user.first_name }} {{ user.last_name }}</h4>
            <ul class="nav flex-column">
                <li class="nav-item"><a class="nav-link" href="/dashboard">Dashboard</a></li>
                <li class="nav-item"><a class="nav-link" href="/donations">Donations</a></li>
                <li class="nav-item"><a class="nav-link" href="/logout">Logout</a></li>
            </ul>
        </div>
        <div class="container p-4">
            <h1>Welcome to the Dashboard</h1>
            <p>{{ content }}</p>
        </div>
    </div>
</body>
</html>
'''

DONATIONS_TEMPLATE = '''
<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <title>Donations</title>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-light bg-light">
        <a class="navbar-brand" href="#">Dashboard</a>
        <div class="collapse navbar-collapse">
            <ul class="navbar-nav mr-auto">
                <li class="nav-item"><a class="nav-link" href="/dashboard">Home</a></li>
                <li class="nav-item"><a class="nav-link" href="/donations">Donations</a></li>
                <li class="nav-item"><a class="nav-link" href="/logout">Logout</a></li>
            </ul>
        </div>
    </nav>
    <div class="container mt-4">
        <h1>Donations</h1>
        <table class="table table-bordered">
            <thead class="thead-light">
                <tr>
                    <th>Donor Name</th>
                    <th>Amount</th>
                    <th>Payment Method</th>
                    <th>Date</th>
                </tr>
            </thead>
            <tbody>
                {% for donation in donations %}
                <tr>
                    <td>{{ donation.donor_name }}</td>
                    <td>{{ donation.amount }}</td>
                    <td>{{ donation.payment_method }}</td>
                    <td>{{ donation.donation_date }}</td>
                </tr>
                {% endfor %}
            </tbody>
        </table>
    </div>
</body>
</html>
'''

if __name__ == '__main__':
    app.run(debug=True)
